@@ -2,7 +2,7 @@
 varying <- function(x, ...) UseMethod("varying") # , x
 
 varying.default <- function(x, g = NULL, any_group = TRUE, use.g.names = TRUE, ...) {
-  if(is.matrix(x) && !inherits(x, "matrix")) return(varying.matrix(x, g, any_group, use.g.names, ...))
+  # if(is.matrix(x) && !inherits(x, "matrix")) return(varying.matrix(x, g, any_group, use.g.names, ...))
   if(!missing(...)) unused_arg_action(match.call(), ...)
   if(is.null(g)) return(.Call(Cpp_varying,x,0L,0L,any_group))
   if(is.atomic(g)) {
@@ -48,6 +48,9 @@ varying.matrix <- function(x, g = NULL, any_group = TRUE, use.g.names = TRUE, dr
   .Call(Cpp_varyingm,x,g[[1L]],g[[2L]],any_group,drop)
 }
 
+varying.zoo <- function(x, ...) if(is.matrix(x)) varying.matrix(x, ...) else varying.default(x, ...)
+varying.units <- varying.zoo
+
 varying.data.frame <- function(x, by = NULL, cols = NULL, any_group = TRUE, use.g.names = TRUE, drop = TRUE, ...) {
   if(!missing(...)) unused_arg_action(match.call(), ...)
 
@@ -88,11 +91,11 @@ varying.pdata.frame <- function(x, effect = 1L, cols = NULL, any_group = TRUE, u
   index <- unclass(findex(x))
   g <- if(length(effect) == 1L) index[[effect]] else finteraction(index[effect], sort = !any_group && .op[["sort"]])
   x <- if(is.null(cols)) fcolsubset(x, attr(x, "names") %!in% names(index[effect])) else colsubset(x, cols)
-  if(!any_group && use.g.names) {
+  res <- if(!any_group && use.g.names) {
     lev <- attr(g, "levels")
-    return(setRnDF(.Call(Cpp_varyingl,x,length(lev),g,any_group,FALSE), lev))
-  }
-  .Call(Cpp_varyingl,x,fnlevels(g),g,any_group,drop)
+    setRnDF(.Call(Cpp_varyingl,x,length(lev),g,any_group,FALSE), lev)
+  } else .Call(Cpp_varyingl,x,fnlevels(g),g,any_group,drop)
+  return(if(any_group) res else unindex_light(res))
 }
 
 varying.grouped_df <- function(x, any_group = TRUE, use.g.names = FALSE, drop = TRUE, keep.group_vars = TRUE, ...) {
