@@ -82,7 +82,9 @@ static SEXP shallow(SEXP dt, SEXP cols, R_len_t n)
   SEXP newdt = PROTECT(allocVector(VECSXP, n)); protecti++;   // to do, use growVector here?
   SET_ATTRIB(newdt, shallow_duplicate(ATTRIB(dt)));
   SET_OBJECT(newdt, OBJECT(dt));
-  if(IS_S4_OBJECT(dt)) newdt = asS4(newdt, TRUE, 1);  // To support S4 objects that include data.table
+  if(IS_S4_OBJECT(dt)) {
+    newdt = PROTECT(asS4(newdt, TRUE, 1)); protecti++;  // To support S4 objects that include data.table
+  }
   //SHALLOW_DUPLICATE_ATTRIB(newdt, dt);  // SHALLOW_DUPLICATE_ATTRIB would be a bit neater but is only available from R 3.3.0
 
   // TO DO: keepattr() would be faster, but can't because shallow isn't merely a shallow copy. It
